# Build -python subpackage
%bcond_without python
# Build -java subpackage
%ifarch %arm
%bcond_with java
%else
%bcond_without java
%endif
# Don't require gtest
%bcond_with gtest

# Major
%define major           9

# Library names
%define libname         %mklibname %{name} %{major}
%define liblite         %mklibname %{name}-lite %{major}
%define libcompiler     %mklibname protoc %{major}
%define develname       %mklibname %{name} -d
%define staticdevelname %mklibname %{name} -d -s


%if %{with python}
%define python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")
%endif

Summary:        Protocol Buffers - Google's data interchange format
Name:           protobuf
Version:        2.6.1
Release:        %mkrel 3
License:        BSD
Group:          Development/Other
URL:            https://github.com/google/protobuf
Source0:        https://github.com/google/protobuf/releases/download/v%{version}/%{name}-%{version}.tar.bz2
Source1:        ftdetect-proto.vim
Patch1:         protobuf-2.5.0-fedora-gtest.patch
BuildRequires:  automake
BuildRequires:  autoconf
BuildRequires:  libtool
BuildRequires:  pkgconfig
%if %{with gtest}
BuildRequires:  gtest-devel
%endif
BuildRequires:  zlib-devel
%if %{with java}
BuildRequires:  maven-local
%endif

%description
Protocol Buffers are a way of encoding structured data in an efficient
yet extensible format. Google uses Protocol Buffers for almost all of
its internal RPC protocols and file formats.

Protocol buffers are a flexible, efficient, automated mechanism for
serializing structured data – think XML, but smaller, faster, and
simpler. You define how you want your data to be structured once, then
you can use special generated source code to easily write and read
your structured data to and from a variety of data streams and using a
variety of languages. You can even update your data structure without
breaking deployed programs that are compiled against the "old" format.

%package -n     %{libname}
Summary:        Runtime library for %{name}
Group:          System/Libraries
Obsoletes:      %{_lib}protobuf6 < %{version}-%{release}

%description -n %{libname}
Protocol Buffers are a way of encoding structured data in an efficient
yet extensible format. Google uses Protocol Buffers for almost all of
its internal RPC protocols and file formats.

Protocol buffers are a flexible, efficient, automated mechanism for
serializing structured data - think XML, but smaller, faster, and
simpler. You define how you want your data to be structured once, then
you can use special generated source code to easily write and read
your structured data to and from a variety of data streams and using a
variety of languages. You can even update your data structure without
breaking deployed programs that are compiled against the "old" format.

This package contains the shared %{name} library.

%package -n     %{liblite}
Summary:        Protocol Buffers lite version
Group:          Development/Other
Obsoletes:      %{_lib}protobuf-lite6 < %{version}-%{release}

%description -n %{liblite}
This package contains a compiled with "optimize_for = LITE_RUNTIME"
version of Google's Protocol Buffers library.

The "optimize_for = LITE_RUNTIME" option causes the compiler to
generate code which only depends libprotobuf-lite, which is much
smaller than libprotobuf but lacks descriptors, reflection, and some
other features.

%package        compiler
Summary:        Protocol Buffers compiler
Group:          Development/Other
Recommends:     %{libname} = %{version}
Recommends:     %{liblite} = %{version}

%description    compiler
This package contains Protocol Buffers compiler for all programming
languages.

%package -n     %{libcompiler}
Summary:        Protocol Buffers compiler shared library
Group:          System/Libraries
Obsoletes:      %{_lib}protoc6 < %{version}-%{release}

%description -n %{libcompiler}
This package contains the Protocol Buffers compiler shared library.

%package -n     %{develname}
Summary:        Protocol Buffers C++ headers and libraries
Group:          Development/Other
Requires:       %{libname} = %{version}
Requires:       %{liblite} = %{version}
Requires:       %{libcompiler} = %{version}
Requires:       %{name}-compiler = %{version}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains Protocol Buffers compiler for all languages and
C++ headers and libraries.

%package -n     %{staticdevelname}
Summary:        Static development files for %{name}
Group:          Development/Other
Requires:       %{develname} = %{version}
Provides:       %{name}-static-devel = %{version}-%{release}

%description -n %{staticdevelname}
This package contains static libraries for Protocol Buffers.

%if %{with python}
%package -n     python-%{name}
Summary:        Python bindings for Google Protocol Buffers
Group:          Development/Python
BuildRequires:  python-devel
BuildRequires:  python-setuptools
Obsoletes:      %{name}-python < 2.3.1
Provides:       %{name}-python = %{version}-%{release}
Conflicts:      %{name}-compiler > %{version}
Conflicts:      %{name}-compiler < %{version}

%description -n python-%{name}
This package contains Python libraries for Google Protocol Buffers.
%endif

%package        vim
Summary:        Vim syntax highlighting for Google Protocol Buffers descriptions
Group:          Development/Other
BuildArch:      noarch
Requires:       vim-enhanced

%description    vim
This package contains syntax highlighting for Google Protocol Buffers
descriptions in Vim editor.

%if %{with java}
%package        java
Summary:        Java Protocol Buffers runtime library
Group:          Development/Java
BuildArch:      noarch
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.easymock:easymock)

Conflicts:      %{name}-compiler > %{version}
Conflicts:      %{name}-compiler < %{version}

%description    java
This package contains Java Protocol Buffers runtime library.

%package	javadoc
Summary:        Javadocs for %{name}-java
Group:          Documentation
BuildArch:      noarch
Requires:       %{name}-java = %{version}-%{release}

%description    javadoc
This package contains the API documentation for %{name}-java.

%endif

%prep
%setup -q
%if %{with gtest}
rm -rf gtest
%patch1 -p1
%endif

chmod 644 examples/*

%if %{with java}
%pom_remove_parent java/pom.xml
%pom_remove_dep org.easymock:easymockclassextension java/pom.xml
rm -rf java/src/test
%endif

%build
iconv -f iso8859-1 -t utf-8 CONTRIBUTORS.txt > CONTRIBUTORS.txt.utf8
mv CONTRIBUTORS.txt.utf8 CONTRIBUTORS.txt
export PTHREAD_LIBS="-lpthread"
./autogen.sh
%configure2_5x

%make

%if %{with python}
pushd python
%{__python} setup.py build
sed -i -e 1d build/lib/google/protobuf/descriptor_pb2.py
popd
%endif

%if %{with java}
pushd java
%mvn_file : %{name}
%mvn_build
popd
%endif

%check
#make check

%install
%makeinstall_std STRIPBINARIES=no INSTALL="%{__install} -p" CPPROG="cp -p"
# we don't want these
find %{buildroot} -name '*.la' -delete

%if %{with python}
pushd python
%{__python} setup.py install --root=%{buildroot} --single-version-externally-managed --record=INSTALLED_FILES --optimize=1
popd
%endif
install -p -m 644 -D %{SOURCE1} %{buildroot}%{_datadir}/vim/vimfiles/ftdetect/proto.vim
install -p -m 644 -D editors/proto.vim %{buildroot}%{_datadir}/vim/vimfiles/syntax/proto.vim

%if %{with java}
pushd java
%mvn_install
popd
%endif

%files -n %{libname}
%doc CHANGES.txt CONTRIBUTORS.txt README.md
%license LICENSE
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}.so.%{major}.*

%files -n %{liblite}
%doc README.md
%license LICENSE
%{_libdir}/lib%{name}-lite.so.%{major}
%{_libdir}/lib%{name}-lite.so.%{major}.*

%files compiler
%doc README.md
%license LICENSE
%{_bindir}/protoc

%files -n %{libcompiler}
%{_libdir}/libprotoc.so.%{major}
%{_libdir}/libprotoc.so.%{major}.*

%files -n %{develname}
%doc examples/add_person.cc examples/addressbook.proto
%doc  examples/list_people.cc examples/Makefile examples/README.txt
%dir %{_includedir}/google
%{_includedir}/google/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}-lite.so
%{_libdir}/libprotoc.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}-lite.pc

%files -n %{staticdevelname}
%{_libdir}/lib%{name}.a
%{_libdir}/lib%{name}-lite.a
%{_libdir}/libprotoc.a

%if %{with python}
%files -n python-%{name}
%dir %{python_sitelib}/google
%{python_sitelib}/google/protobuf/
%{python_sitelib}/protobuf-%{version}-py%{pyver}.egg-info/
%{python_sitelib}/protobuf-%{version}-py%{pyver}-nspkg.pth
%doc python/README.txt
%doc examples/add_person.py examples/list_people.py examples/addressbook.proto
%endif

%files vim
%{_datadir}/vim/vimfiles/ftdetect/proto.vim
%{_datadir}/vim/vimfiles/syntax/proto.vim

%if %{with java}
%files java -f java/.mfiles
%doc examples/AddPerson.java examples/ListPeople.java

%files javadoc -f java/.mfiles-javadoc
%endif


%changelog
* Tue Feb 16 2016 umeabot <umeabot> 2.6.1-3.mga6
+ Revision: 962148
- Mageia 6 Mass Rebuild

* Tue Nov 10 2015 pterjan <pterjan> 2.6.1-2.mga6
+ Revision: 900408
- Disable java subpackage on arm

* Wed Aug 26 2015 daviddavid <daviddavid> 2.6.1-1.mga6
+ Revision: 869867
- new version: 2.6.1
- update URL and Source URL
- drop java-fixes patch, use pom macros instead
- update java BuildRequires
- build with xmvn
- update doc files lists
- switch to %%license macro

* Wed Aug 26 2015 daviddavid <daviddavid> 2.6.0-7.mga6
+ Revision: 869580
- rebuild for new gcc 5.2.1

* Mon Jan 19 2015 daviddavid <daviddavid> 2.6.0-6.mga5
+ Revision: 811482
- build with xmvn
- use .mfiles generated during build
- update Requires for -java subpackage
- fix Group

* Wed Oct 15 2014 umeabot <umeabot> 2.6.0-5.mga5
+ Revision: 740898
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

  + tv <tv>
    - rebuild for missing pythoneggs deps
    - s/uggests:/Recommends:/

* Mon Sep 01 2014 luigiwalser <luigiwalser> 2.6.0-2.mga5
+ Revision: 670298
- library major is now 9
- 2.6.0
- rediff patch 2

  + pterjan <pterjan>
    - Rebuild for new Python
    - Do not BuildRequires maven-local when java build is disabled

* Tue Dec 31 2013 dmorgan <dmorgan> 2.5.0-1.mga4
+ Revision: 563486
- New version ( needed by infinispan and hibernate4)

* Tue Oct 22 2013 umeabot <umeabot> 2.4.1-7.mga4
+ Revision: 544923
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.4.1-6.mga4
+ Revision: 500483
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Jan 29 2013 oden <oden> 2.4.1-5.mga3
+ Revision: 393188
- duh!, fix the problem properly (br: zlib-devel)

* Tue Jan 29 2013 oden <oden> 2.4.1-4.mga3
+ Revision: 393180
- fix build
- add one missing header

* Sun Jan 13 2013 umeabot <umeabot> 2.4.1-3.mga3
+ Revision: 378251
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Oct 26 2012 fwang <fwang> 2.4.1-2.mga3
+ Revision: 310142
- sync with fedora spec

* Fri Oct 26 2012 fwang <fwang> 2.4.1-1.mga3
+ Revision: 310125
- disable check till gcc 4.7 problem fixed
- use mvn
- cleanup spec and lock libmajor

* Fri Nov 18 2011 pterjan <pterjan> 2.4.1-1.mga2
+ Revision: 168995
- Fix groups
- Update to 2.4.1

* Fri May 20 2011 dmorgan <dmorgan> 2.3.0-11.mga1
+ Revision: 99925
- Define the major
- Sync packages names with mandriva ( better libification)

* Thu Apr 28 2011 dmorgan <dmorgan> 2.3.0-10.mga1
+ Revision: 93342
- Rename python package name

  + pterjan <pterjan>
    - Drop ldconfig scriptlets

* Thu Apr 28 2011 dmorgan <dmorgan> 2.3.0-9.mga1
+ Revision: 93292
- Rebuild because of missing python package

* Wed Apr 27 2011 dmorgan <dmorgan> 2.3.0-8.mga1
+ Revision: 91988
- Rebuild after bootstrapping
- imported package protobuf


* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jan 13 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 2.3.0-6
- Fix java subpackage bugs #669345 and #669346
- Use new maven plugin names
- Use mavenpomdir macro for pom installation

* Mon Jul 26 2010 David Malcolm <dmalcolm@redhat.com> - 2.3.0-5
- generalize hardcoded reference to 2.6 in python subpackage %%files manifest

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 2.3.0-4
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Thu Jul 15 2010 James Laska <jlaska@redhat.com> - 2.3.0-3
- Correct use of %%bcond macros

* Wed Jul 14 2010 James Laska <jlaska@redhat.com> - 2.3.0-2
- Enable python and java sub-packages

* Tue May 4 2010 Conrad Meyer <konrad@tylerc.org> - 2.3.0-1
- bump to 2.3.0

* Wed Sep 30 2009 Lev Shamardin <shamardin@gmail.com> - 2.2.0-2
- added export PTHREAD_LIBS="-lpthread"

* Fri Sep 18 2009 Lev Shamardin <shamardin@gmail.com> - 2.2.0-1
- Upgraded to upstream protobuf-2.2.0
- New -lite packages

* Sun Mar 01 2009 Caolán McNamra <caolanm@redhat.com> - 2.0.2-8
- add stdio.h for sprintf, perror, etc.

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Tue Dec 23 2008 Lev Shamardin <shamardin@gmail.com> - 2.0.2-6
- Small fixes for python 2.6 eggs.
- Temporarily disabled java subpackage due to build problems, will be fixed and
  turned back on in future.

* Thu Nov 27 2008 Lev Shamardin <shamardin@gmail.com> - 2.0.2-5
- No problems with ppc & ppc64 arch in rawhide, had to do a release bump.

* Sat Nov 22 2008 Lev Shamardin <shamardin@gmail.com> - 2.0.2-4
- Added patch from subversion r70 to workaround gcc 4.3.0 bug (see
  http://code.google.com/p/protobuf/issues/detail?id=45 for more
  details).

* Tue Nov 11 2008 Lev Shamardin <shamardin@gmail.com> - 2.0.2-3
- Added conflicts to java and python subpackages to prevent using with
  wrong compiler versions.
- Fixed license.
- Fixed BuildRequires for -python subpackage.
- Fixed Requires and Group for -javadoc subpackage.
- Fixed Requires for -devel subpackage.
- Fixed issue with wrong shebang in descriptor_pb2.py.
- Specify build options via --with/--without.
- Use Fedora-packaged gtest library instead of a bundled one by
  default (optional).

* Fri Oct 31 2008 Lev Shamardin <shamardin@gmail.com> - 2.0.2-2
- Use python_sitelib macro instead of INSTALLED_FILES.
- Fix the license.
- Fix redundant requirement for -devel subpackage.
- Fix wrong dependences for -python subpackage.
- Fix typo in requirements for -javadoc subpackage.
- Use -p option for cp and install to preserve timestamps.
- Remove unneeded ldconfig call for post scripts of -devel subpackage.
- Fix directories ownership.

* Sun Oct 12 2008 Lev Shamardin <shamardin@gmail.com> - 2.0.2-1
- Update to version 2.0.2
- New -java and -javadoc subpackages.
- Options to disable building of -python and -java* subpackages

* Mon Sep 15 2008 Lev Shamardin <shamardin@gmail.com> - 2.0.1-2
- Added -p switch to install commands to preserve timestamps.
- Fixed Version and Libs in pkgconfig script.
- Added pkgconfig requires for -devel package.
- Removed libtool archives from -devel package.

* Thu Sep 04 2008 Lev Shamardin <shamardin@gmail.com> - 2.0.1-1
- Updated to 2.0.1 version.

* Wed Aug 13 2008 Lev Shamardin <shamardin@gmail.com> - 2.0.0-0.1.beta
- Initial package version. Credits for vim subpackage and pkgconfig go
  to Rick L Vinyard Jr <rvinyard@cs.nmsu.edu>
